# Step 2: Assess AI Potential and Usage
### On this page
  * [AI Potential of Business Capabilities](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption-assess-potential#ai-potential-of-business-capabilities)
  * [AI Potential and Usage of Applications](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption-assess-potential#ai-potential-and-usage-of-applications)
  * [Business Value and Usage of AI Agents](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption-assess-potential#business-value-and-usage-of-ai-agents)


Analyze your landscape to understand the current potential and usage of AI technologies.
After collecting initial AI-related data, use reports to analyze your AI landscape. Identify areas where AI can have the most impact. This analysis helps you prioritize AI investments and strategies to maximize benefits.
